#!/bin/sh

# Script to mount ramfs /etc on cramfs demo system

if ! [ -f /proc/filesystems ]; then
    mount /proc
    umount='umount /proc'
fi

# Only run if root is really on cramfs; don't run during adsrootbuilder
# since that would make it see every file in /etc and /dev as used.
if ! grep -q "/dev/root / cramfs" /proc/mounts; then
	echo "Skipping mountetc; root is not in cramfs."
	if [ -n "${umount}" ]; then
	        ${umount}
	fi
	exit
fi

echo 'Migrating /etc to ramfs...'

mkdir /var/etc
if ! mount -n -t ramfs -o rw,size=2m ramfs /var/etc ; then
	echo 'Failed to mount ramfs /etc!'
	echo 'Warning: /etc will not be writable!'
	exit
fi

tar -C /etc -cf - . | tar -C /var/etc -xf -

# Use the 'bind' mount function to mount a single
#  ramfs entity in 2 places at once
echo 'Binding ramfs /var/etc to /etc...'
if ! mount -n -o bind /var/etc /etc ; then
        echo 'Failed to mount ramfs /etc!'
	echo 'Warning: /etc will not be writable!'
	exit
fi

echo "Migrating /dev to ramfs..."

mkdir /var/dev
if ! mount -n -t ramfs -o rw,size=2m ramfs /var/dev ; then
	echo 'Failed to mount ramfs /dev!'
	echo 'Warning: /dev will not be writable!'
	exit
fi

tar -C /dev -cf - . | tar -C /var/dev -xf -

# Use the 'bind' mount function to mount a single
#  ramfs entity in 2 places at once
echo 'Binding ramfs /var/dev to /dev...'
if ! mount -n -o bind /var/dev /dev ; then
        echo 'Failed to mount ramfs /dev!'
        echo 'Warning: /dev will not be writable!'
        exit
fi

if [ -n "${umount}" ]; then
        ${umount}
fi

